##  Step 3: Create Custom Fields on Fact Sheets
Create custom fields for risk assessment on the fact sheet types for which you plan to assess risks, such as applications, IT components, data objects, or providers.
To create custom fields on a fact sheet, follow these steps:
  1. In the administration area, navigate to the Meta Model Configuration section.
  2. Select a fact sheet type for which you plan to run risk assessments. You land on the fact sheet configuration page.
  3. Create a dedicated subsection for risk assessment. To do that, select any section, click Add subsection, then create a name and label for the subsection in the right-side panel. Save the changes.
  4. To create custom fields within the subsection, select it, click Add field, then specify the field details in the right-side panel. Use the following table for reference.
Key | Field Type | Displayed As | Label | Values and Labels
---|---|---|---|---
riskAssessmentScore | String | Text | Aggregated Risk Score | N/a
technicalRiskLevel | Single Select | Status | Risk Level |
     * lowRisk: Low risk
     * mediumRisk: Medium risk
     * highRisk: High risk


  5. Save the changes.


Custom fields are added to the fact sheet. If needed, add the same custom fields to more fact sheet types.
